# PriceChangeParams


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**price_change_option** | [**PriceChangeOption**](PriceChangeOption.md) |  | [optional] [default to PriceChangeOption.NOCHANGE]
**price_increase_percentage** | **float** | Specifies the percentage by which the price of the charge should change each time the subscription renews. Only applicable if the value of the &#x60;priceChangeOption&#x60; field is &#x60;SpecificPercentageValue&#x60;.  | [optional] 

## Example

```python
from zuora_sdk.models.price_change_params import PriceChangeParams

# TODO update the JSON string below
json = "{}"
# create an instance of PriceChangeParams from a JSON string
price_change_params_instance = PriceChangeParams.from_json(json)
# print the JSON string representation of the object
print(PriceChangeParams.to_json())

# convert the object into a dict
price_change_params_dict = price_change_params_instance.to_dict()
# create an instance of PriceChangeParams from a dict
price_change_params_from_dict = PriceChangeParams.from_dict(price_change_params_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


